djangoflow_websocket library
Classes
-
DjangoflowWebsocketBlocBuilder<
C extends DjangoflowWebsocketCubitBase> -
DjangoflowWebsocketBlocBuilder is basically a
BlocBuilder<DjangoflowWebsocketCubit, DjangoflowWebsocketState>widget that makes it easier to use. -
DjangoflowWebsocketBlocListener<
C extends DjangoflowWebsocketCubitBase> -
DjangoflowWebsocketBlocListener is basically a
BlocListener<DjangoflowWebsocketCubit, DjangoflowWebsocketState>that makes it easier to use. By default(if null)listenWhenis set to (previous, current) => previous != current - DjangoflowWebsocketConfig
- DjangoflowWebsocketCubit
-
DjangoflowWebsocketCubit is a Cubit which manages a websocket connection to a server using
WebSocketChannel. and emits DjangoflowWebsocketStates. It also handles automatic reconnection. - DjangoflowWebsocketCubitBase
- DjangoflowWebsocketState
- DjangoflowWebsocketState is the state emitted by DjangoflowWebsocketCubit It contains the last message received from the server and the connection state message
Exceptions / Errors
- JsonParsingException
- Exception class to catch json parsing errors